cmoncrawl.processor.pipeline.pipeline.ProcessorPipeline — CmonCrawl 1.0.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# cmoncrawl.processor.pipeline.pipeline.ProcessorPipeline

class cmoncrawl.processor.pipeline.pipeline.ProcessorPipeline(router: IRouter, downloader: IDownloader, outstreamer: IStreamer)
  __init__(router: IRouter, downloader: IDownloader, outstreamer: IStreamer)

  Methods

  `__init__`(router, downloader, outstreamer) |
  `process_domain_record`(domain_record, ...) |